Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(12)

Unified Diff: include/v8-profiler.h

Issue 22347003: Deprecate self and total time getters and total sample count getter on CpuProfileNode (Closed) Base URL: https://v8.googlecode.com/svn/branches/bleeding_edge
Patch Set: Added GetHitCount Created 7 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: include/v8-profiler.h
diff --git a/include/v8-profiler.h b/include/v8-profiler.h
index f2128ce0bed6bb35ebcbdca72cfd6e56d892f892..e538f4a84068e6836567453eddb1b00b7d0ccbd4 100644
--- a/include/v8-profiler.h
+++ b/include/v8-profiler.h
@@ -61,20 +61,27 @@ class V8_EXPORT CpuProfileNode {
* Returns total (self + children) execution time of the function,
* in milliseconds, estimated by samples count.
*/
- double GetTotalTime() const;
+ V8_DEPRECATED(double GetTotalTime() const);
/**
* Returns self execution time of the function, in milliseconds,
* estimated by samples count.
*/
- double GetSelfTime() const;
+ V8_DEPRECATED(double GetSelfTime() const);
/** Returns the count of samples where function exists. */
- double GetTotalSamplesCount() const;
+ V8_DEPRECATED(double GetTotalSamplesCount() const);
- /** Returns the count of samples where function was currently executing. */
+ /** DEPRECATED. Please use GetHitCount instead.
+ * Returns the count of samples where function was currently executing.
+ */
double GetSelfSamplesCount() const;
Sven Panne 2013/08/08 13:05:38 Can't we use V8_DEPRECATED here?
yurys 2013/08/08 13:37:41 We need to change Chrome DevTools to use the new G
+ /**
+ * Returns the count of samples where the function was currently executing.
+ */
+ unsigned GetHitCount() const;
+
/** Returns function entry UID. */
unsigned GetCallUid() const;
« no previous file with comments | « no previous file | src/api.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698